@@ -18,6 +18,7 @@ EXTENSIONS = {
     'cc': {'text', 'c++'},
     'cfg': {'text'},
     'chs': {'text', 'c2hs'},
+    'cjs': {'text', 'javascript'},
     'clj': {'text', 'clojure'},
     'cljc': {'text', 'clojure'},
     'cljs': {'text', 'clojure', 'clojurescript'},
@@ -311,6 +312,7 @@ NAMES = {
     'Pipfile': EXTENSIONS['toml'],
     'Pipfile.lock': EXTENSIONS['json'],
     'PKGBUILD': {'text', 'bash', 'pkgbuild', 'alpm'},
+    'poetry.lock': EXTENSIONS['toml'],
     'pylintrc': EXTENSIONS['ini'] | {'pylintrc'},
     'README': EXTENSIONS['txt'],
     'Rakefile': EXTENSIONS['rb'],
